# coding=utf-8
import csv
import logging
import sys
import traceback

from warning_counter import MsgCounterHandler
from web.models import StudySubject, Appointment

logger = logging.getLogger(__name__)


class SubjectExporter(object):
    def __init__(self, filename):
        # type: (str) -> None
        self.filename = filename
        self.exported_count = 0
        self.warning_count = 0

    def execute(self):
        self.exported_count = 0
        self.warning_count = 0

        warning_counter = MsgCounterHandler()
        logging.getLogger('').addHandler(warning_counter)

        with open(self.filename, 'w') as csv_file:
            data = self.get_subjects_as_array()
            writer = csv.writer(csv_file, quotechar=str(u'"'))
            for row in data:
                writer.writerow([s.encode("utf-8") for s in row])
                self.exported_count += 1

        if "WARNING" in warning_counter.level2count:
            self.warning_count = warning_counter.level2count["WARNING"]
        logging.getLogger('').removeHandler(warning_counter)

    def get_summary(self):
        result = "<p>Number of entries: <b>" + str(self.exported_count) + "</b></p>"
        style = ''
        if self.warning_count > 0:
            style = ' color="brown" '
        result += "<p><font " + style + ">Number of raised warnings: <b>" + str(self.warning_count) + "</b></font></p>"

        return result

    def get_subjects_as_array(self):
        result = []
        study_subjects = StudySubject.objects.filter(excluded=True)
        for study_subject in study_subjects:
            result.append([study_subject.nd_number])
        return result


class VisitExporter(object):
    def __init__(self, filename):
        # type: (str) -> None
        self.filename = filename
        self.exported_count = 0
        self.warning_count = 0

    def execute(self):
        self.exported_count = 0
        self.warning_count = 0

        warning_counter = MsgCounterHandler()
        logging.getLogger('').addHandler(warning_counter)

        with open(self.filename, 'w') as csv_file:
            data = self.get_appointments_as_array()
            writer = csv.writer(csv_file, quotechar=str(u'"'))
            for row in data:
                writer.writerow([s.encode("utf-8") for s in row])
                self.exported_count += 1

        if "WARNING" in warning_counter.level2count:
            self.warning_count = warning_counter.level2count["WARNING"]
        logging.getLogger('').removeHandler(warning_counter)

    def get_summary(self):
        result = "<p>Number of entries: <b>" + str(self.exported_count) + "</b></p>"
        style = ''
        if self.warning_count > 0:
            style = ' color="brown" '
        result += "<p><font " + style + ">Number of raised warnings: <b>" + str(self.warning_count) + "</b></font></p>"

        return result

    def get_appointments_as_array(self):
        result = []
        appointments = Appointment.objects.filter(status=Appointment.APPOINTMENT_STATUS_FINISHED)
        for appointment in appointments:
            try:
                if appointment.visit is not None:
                    result.append([appointment.visit.subject.nd_number, str(appointment.visit.visit_number - 1)])
            except:
                traceback.print_exc(file=sys.stdout)
                logger.warn("Problem with exporting appointment: " + str(appointment.id))
        return result
