# coding=utf-8

import logging

from django.test import TestCase

from web.importer import TnsCsvSubjectImportReader
from web.tests.functions import get_resource_path
from web.importer import MsgCounterHandler

logger = logging.getLogger(__name__)


class TestTnsCsvSubjectReader(TestCase):

    def setUp(self):
        self.warning_counter = MsgCounterHandler()
        logging.getLogger('').addHandler(self.warning_counter)

    def tearDown(self):
        logging.getLogger('').removeHandler(self.warning_counter)

    def test_load_data(self):
        filename = get_resource_path('tns_subjects_import.csv')
        study_subjects = TnsCsvSubjectImportReader().load_data(filename)
        self.assertEqual(3, len(study_subjects))
        study_subject = study_subjects[1]
        self.assertEqual("John2", study_subject.subject.first_name)
        self.assertEqual("Doe2", study_subject.subject.last_name)
        self.assertEqual("cov-222333", study_subject.screening_number)
        self.assertEqual("cov-222333", study_subject.nd_number)
        self.assertEqual("621000000", study_subject.subject.phone_number)
        self.assertTrue("Gregory House2" in study_subject.comments)

        self.assertEqual(1, study_subject.subject.date_born.day)
        self.assertEqual(2, study_subject.subject.date_born.month)
        self.assertEqual(1977, study_subject.subject.date_born.year)

        self.assertIsNotNone(study_subject.study)
        self.assertEqual(0, self.get_warnings_count())

    def get_warnings_count(self):
        if "WARNING" in self.warning_counter.level2count:
            return self.warning_counter.level2count["WARNING"]
        else:
            return 0
